==> shared_package_flutter-0.0.15.tar.gz: lib/components/login/forgot_new_password.dart <==
import 'package:flutter/material.dart';
import 'package:shared_package_flutter/components/showDialog/show_dialog.dart';

class ForgotNewPasswordParam{
  Color colorApp;
  Function( String ) onSuccess;

  ForgotNewPasswordParam({
    this.colorApp,
    this.onSuccess
  });
}

class ForgotNewPassword extends StatefulWidget{
  @override
  _ForgotNewPassword createState() => _ForgotNewPassword();
}

class _ForgotNewPassword extends State<ForgotNewPassword>{
  final GlobalKey<FormState> _keyValidationForm = GlobalKey<FormState>();
  ForgotNewPasswordParam _paramModel;

  TextEditingController _textEditingControllerNewPassword = TextEditingController( );
  TextEditingController _textEditingControllerRepeatNewPassword = TextEditingController( );

  final FocusNode _repeatNewPasswordFocus = FocusNode();
  final FocusNode _buttonSaveFocus = FocusNode();

  int _stateSave = 0;

  Widget buttonSave(){
    if( _stateSave == 0 ){
      return Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Icon( Icons.save ),
          Padding( padding: EdgeInsets.only( right: 15 ) ),
          Text(
            "Salvar",
            style: TextStyle( fontSize: 20.0 ),
          )
        ],
      );
    }
    else if( _stateSave == 1 ){
      return SizedBox(
        height: 20,
        width: 20,
        child: CircularProgressIndicator(
          value: null,
          valueColor: AlwaysStoppedAnimation<Color>( Colors.white ),
        ),
      );
    }
    else if( _stateSave == 2 ){
      return Icon( Icons.check, color: Colors.white );
    }
    else{
      return Text(
        "Erro",
        style: TextStyle( fontSize: 20.0 ),
      );
    }
  }

  void buttonSaveUser() async{

    if( _stateSave == 3 ){
      setState(() {
        _stateSave = 0;
      });
    }

    try{

      if ( _keyValidationForm.currentState.validate() ) {

        if( _textEditingControllerNewPassword.text.toLowerCase() == _textEditingControllerRepeatNewPassword.text.toLowerCase() ){

          _paramModel.onSuccess( _textEditingControllerNewPassword.text );
        }
        else{

          setState(() {
            _stateSave = 3;
            FocusScope.of( context ).requestFocus( _buttonSaveFocus );
          });

          ShowDialog.show(
              context,
              ShowDialogParam(
                "Erro",
                "A nova senha de confirmação está diferente"
              )
            );
        }
      }

    }catch( exception ){
      setState(() {
        _stateSave = 3;
        FocusScope.of( context ).requestFocus( _buttonSaveFocus );
      });

      ShowDialog.show(
        context,
        ShowDialogParam(
          "Erro",
          "Ocorreu um erro ao trocar a senha"
        )
      );
    }
  }

  @override
  Widget build( BuildContext context ){

    Object obj = ModalRoute.of( context ).settings.arguments;
    if( null != obj && obj.runtimeType == ForgotNewPasswordParam ){
      _paramModel = obj as ForgotNewPasswordParam;
    }
    else{

      return Scaffold(
        backgroundColor: Colors.grey,
        body: Center(
          child: Text(
            "Erro ao abrir a tela para definir nova senha, parametros não informado",
            style: TextStyle( fontSize: 20 )
          )
        )
      );
    }

    return Scaffold(
      appBar: AppBar(
        title: Text( "Definir nova senha" ),
      ),
      body: Container(
        padding: EdgeInsets.only( left: 20.0, right: 20.0 ),
        child: Form(
          key: _keyValidationForm,
          child: ListView(
            children: <Widget>[
              Container(
                padding: EdgeInsets.only( top: 20 ),
                child: TextFormField(
                  controller: _textEditingControllerNewPassword,
                  keyboardType: TextInputType.text,
                  textInputAction: TextInputAction.next,
                  validator: _validateNewPassword,
                  obscureText: true,
                  autofocus: true,
                  onFieldSubmitted: ( String value ) {
                    FocusScope.of( context ).requestFocus( _repeatNewPasswordFocus );
                  },
                  decoration: InputDecoration(
                    labelText: "Nova senha"
                  ),
                )
              ),
              Container(
                padding: EdgeInsets.only( top: 20 ),
                child: TextFormField(
                  focusNode: _repeatNewPasswordFocus,
                  controller: _textEditingControllerRepeatNewPassword,
                  keyboardType: TextInputType.text,
                  textInputAction: TextInputAction.next,
                  validator: _validateRepeatNewPassword,
                  obscureText: true,
                  onFieldSubmitted: ( String value ) {
                    FocusScope.of( context ).requestFocus( _buttonSaveFocus );
                  },
                  decoration: InputDecoration(
                    labelText: "Confirme a nova senha"
                  ),
                )
              ),
              Container(
                margin: EdgeInsets.only( top: 50.0, left: 80.0, right: 80.0 ),
                width: double.infinity,
                child: RaisedButton(
                  focusNode: _buttonSaveFocus,
                  color: _stateSave == 3 ? Colors.redAccent : _paramModel.colorApp,
                  textColor: Colors.white,
                  elevation: 5.0,
                  padding: EdgeInsets.only( top: 16.0, bottom: 16.0 ),
                  child: buttonSave(),
                  onHighlightChanged: ( isPressed ){
                    if( _keyValidationForm.currentState.validate() ){
                      if( _stateSave == 0 ){
                        setState(() {
                          _stateSave = 1;
                        });
                      }
                    }
                  },
                  onPressed: buttonSaveUser
                )
              )
            ],
          )
        )
      )
    );
  }
}

String _validateNewPassword( String value ) {
  return value.trim().isEmpty ? "Preencha o campo nova senha" : null;
}

String _validateRepeatNewPassword( String value ) {
  return value.trim().isEmpty ? "Preencha o campo confirme a nova senha" : null;
}

==> shared_package_flutter-0.0.17.tar.gz: lib/components/login/forgot_new_password.dart <==
import 'package:flutter/material.dart';
import 'package:shared_package_flutter/components/showDialog/show_dialog.dart';

class ForgotNewPasswordParam{
  Color colorApp;
  Future<bool> Function( String newPassword ) onReceivePassword;

  ForgotNewPasswordParam(
    this.colorApp,
    {
      this.onReceivePassword
    }
  );
}

class ForgotNewPassword extends StatefulWidget{
  @override
  _ForgotNewPassword createState() => _ForgotNewPassword();
}

class _ForgotNewPassword extends State<ForgotNewPassword>{
  final GlobalKey<FormState> _keyValidationForm = GlobalKey<FormState>();
  ForgotNewPasswordParam _paramModel;

  TextEditingController _textEditingControllerNewPassword = TextEditingController( );
  TextEditingController _textEditingControllerRepeatNewPassword = TextEditingController( );

  final FocusNode _repeatNewPasswordFocus = FocusNode();
  final FocusNode _buttonSaveFocus = FocusNode();

  int _stateSave = 0;

  Widget buttonSave(){
    if( _stateSave == 0 ){
      return Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: <Widget>[
          Icon( Icons.save ),
          Padding( padding: EdgeInsets.only( right: 15 ) ),
          Text(
            "Salvar",
            style: TextStyle( fontSize: 20.0 ),
          )
        ],
      );
    }
    else if( _stateSave == 1 ){
      return SizedBox(
        height: 20,
        width: 20,
        child: CircularProgressIndicator(
          value: null,
          valueColor: AlwaysStoppedAnimation<Color>( Colors.white ),
        ),
      );
    }
    else if( _stateSave == 2 ){
      return Icon( Icons.check, color: Colors.white );
    }
    else{
      return Text(
        "Erro",
        style: TextStyle( fontSize: 20.0 ),
      );
    }
  }

  void buttonSaveUser() async{

    if( _stateSave == 3 ){
      setState(() {
        _stateSave = 0;
      });
    }

    try{

      if ( _keyValidationForm.currentState.validate() ) {

        if( _textEditingControllerNewPassword.text.toLowerCase() == _textEditingControllerRepeatNewPassword.text.toLowerCase() ){

          if( await _paramModel.onReceivePassword( _textEditingControllerNewPassword.text ) ){

            // Volta para a tela de login
            Navigator.pop( context );
            Navigator.pop( context );
          }
          else{
            setState(() {
              _stateSave = 3;
              FocusScope.of( context ).requestFocus( _buttonSaveFocus );
            });

            ShowDialog.show(
              context,
              ShowDialogParam(
                "Erro",
                "Ocorreu um erro ao trocar a senha"
              )
            );
          }
        }
        else{

          setState(() {
            _stateSave = 3;
            FocusScope.of( context ).requestFocus( _buttonSaveFocus );
          });

          ShowDialog.show(
              context,
              ShowDialogParam(
                "Erro",
                "A nova senha de confirmação está diferente"
              )
            );
        }
      }

    }catch( exception ){
      setState(() {
        _stateSave = 3;
        FocusScope.of( context ).requestFocus( _buttonSaveFocus );
      });

      ShowDialog.show(
        context,
        ShowDialogParam(
          "Erro",
          "Ocorreu um erro ao trocar a senha"
        )
      );
    }
  }

  @override
  Widget build( BuildContext context ){

    Object obj = ModalRoute.of( context ).settings.arguments;
    if( null != obj && obj.runtimeType == ForgotNewPasswordParam ){
      _paramModel = obj as ForgotNewPasswordParam;
    }
    else{

      return Scaffold(
        backgroundColor: Colors.grey,
        body: Center(
          child: Text(
            "Erro ao abrir a tela para definir nova senha, parametros não informado",
            style: TextStyle( fontSize: 20 )
          )
        )
      );
    }

    return Scaffold(
      appBar: AppBar(
        title: Text( "Definir nova senha" ),
      ),
      body: Container(
        padding: EdgeInsets.only( left: 20.0, right: 20.0 ),
        child: Form(
          key: _keyValidationForm,
          child: ListView(
            children: <Widget>[
              Container(
                padding: EdgeInsets.only( top: 20 ),
                child: TextFormField(
                  controller: _textEditingControllerNewPassword,
                  keyboardType: TextInputType.text,
                  textInputAction: TextInputAction.next,
                  validator: _validateNewPassword,
                  obscureText: true,
                  autofocus: true,
                  onFieldSubmitted: ( String value ) {
                    FocusScope.of( context ).requestFocus( _repeatNewPasswordFocus );
                  },
                  decoration: InputDecoration(
                    labelText: "Nova senha"
                  ),
                )
              ),
              Container(
                padding: EdgeInsets.only( top: 20 ),
                child: TextFormField(
                  focusNode: _repeatNewPasswordFocus,
                  controller: _textEditingControllerRepeatNewPassword,
                  keyboardType: TextInputType.text,
                  textInputAction: TextInputAction.next,
                  validator: _validateRepeatNewPassword,
                  obscureText: true,
                  onFieldSubmitted: ( String value ) {
                    FocusScope.of( context ).requestFocus( _buttonSaveFocus );
                  },
                  decoration: InputDecoration(
                    labelText: "Confirme a nova senha"
                  ),
                )
              ),
              Container(
                margin: EdgeInsets.only( top: 50.0, left: 80.0, right: 80.0 ),
                width: double.infinity,
                child: RaisedButton(
                  focusNode: _buttonSaveFocus,
                  color: _stateSave == 3 ? Colors.redAccent : _paramModel.colorApp,
                  textColor: Colors.white,
                  elevation: 5.0,
                  padding: EdgeInsets.only( top: 16.0, bottom: 16.0 ),
                  child: buttonSave(),
                  onHighlightChanged: ( isPressed ){
                    if( _keyValidationForm.currentState.validate() ){
                      if( _stateSave == 0 ){
                        setState(() {
                          _stateSave = 1;
                        });
                      }
                    }
                  },
                  onPressed: buttonSaveUser
                )
              )
            ],
          )
        )
      )
    );
  }
}

String _validateNewPassword( String value ) {
  return value.trim().isEmpty ? "Preencha o campo nova senha" : null;
}

String _validateRepeatNewPassword( String value ) {
  return value.trim().isEmpty ? "Preencha o campo confirme a nova senha" : null;
}
